eapol/eapol_framework/eapol_symbian/am/type/gsmsim/symbian/plugin/inc/EapSimDbUtils.h
branchRCL_3
changeset 18 bad0cc58d154
parent 2 1c7bc153c08e
child 19 c74b3d9f6b9e
--- a/eapol/eapol_framework/eapol_symbian/am/type/gsmsim/symbian/plugin/inc/EapSimDbUtils.h	Thu Aug 19 09:58:27 2010 +0300
+++ b/eapol/eapol_framework/eapol_symbian/am/type/gsmsim/symbian/plugin/inc/EapSimDbUtils.h	Tue Aug 31 15:16:37 2010 +0300
@@ -16,7 +16,7 @@
 */
 
 /*
-* %version: 10 %
+* %version: 8.1.7 %
 */
 
 #ifndef _EAPSIMDBUTILS_H_
@@ -29,21 +29,10 @@
 
 // LOCAL CONSTANTS
 
-#ifdef SYMBIAN_SECURE_DBMS
-// For EAP SIM secure database.
-// Full path is not needed. The database eapsim.dat will be saved in the 
-// data cage path for DBMS. So it will be in "\private\100012a5\eapsim.dat" in C: drive.
-// The maximum length of database name is 0x40 (KDbMaxName) , which is defined in d32dbms.h.
-
-_LIT(KDatabaseName, "c:eapsim.dat");
+// For EAP-SIM private database. Database will be in the private folder of EAP-server (20026FCB).
+// The maximum length of database name is 0x40 (KDbMaxName), which is defined in d32dbms.h.
 
-_LIT(KSecureUIDFormat, "SECURE[102072e9]"); // For the security policy.
-
-#else
-
-_LIT(KDatabaseName, "c:\\system\\data\\eapsim.dat");
-
-#endif //#ifdef SYMBIAN_SECURE_DBMS
+_LIT(KEapSimDatabaseName, "eapsim.dat");
 
 _LIT(KSimTableName, "eapsim");
 
@@ -54,8 +43,8 @@
 public:
 	
 	static void OpenDatabaseL(
-		RDbNamedDatabase& aDatabase, 
-		RDbs& aSession, 
+		RDbNamedDatabase& aDatabase,
+		RFs& aFileServerSession,
 		const TIndexType aIndexType,
 		const TInt aIndex,
 		const eap_type_value_e aTunnelingType);
@@ -99,7 +88,6 @@
 		const TIndexType aIndexType,
 		const TInt aIndex,
 		const eap_type_value_e aTunnelingType);
-
 };
 
 #endif // _EAPSIMDBUTILS_H_